import { useContext, useMemo, useEffect } from "react";
import { Grid, Skeleton } from "@mui/material";
import { Status } from "../../common/Status";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

function createRequest(id) {
  return {
    ioc_id: id
  };
}

export const IOCStatus = ({ id, hideAlerts }) => {
  const client = useContext(apiContext);

  const params = useMemo(() => createRequest(id), [id]);

  const {
    wrapper: callFetchIocAlerts,
    value: iocAlert,
    abort: abortCallFetchIocAlerts
  } = useAPIMethod({
    fcn: client.apis.IOCs.fetchIocAlerts,
    params,
    call: false
  });

  const {
    value: iocStateStatus,
    loading: fetchIocStatusLoading,
    dataReady: iocStatusReady
  } = useAPIMethod({
    fcn: client.apis.IOCs.fetchIocStatus,
    params
  });

  useEffect(() => {
    if (!hideAlerts) {
      callFetchIocAlerts();
    }

    return () => {
      abortCallFetchIocAlerts();
    };
  }, [iocStateStatus, hideAlerts]);

  return (
    <Grid
      container
      direction="column"
      justifyContent="center"
      alignItems="center"
    >
      {fetchIocStatusLoading || !iocStatusReady ? (
        <Skeleton
          variant="circular"
          height={20}
          width={20}
        />
      ) : (
        <Status
          state={iocStateStatus}
          alert={iocAlert}
          hideAlerts={hideAlerts}
        />
      )}
    </Grid>
  );
};
