import {
  Table,
  InternalLink,
  EllipsisText,
  EmptyValue
} from "@ess-ics/ce-ui-common";
import { IOCDescription } from "./IOCDescription";
import { IOCStatus } from "./IOCStatus";

const exploreIocsColumns = [
  {
    field: "status",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  {
    field: "namingName",
    headerName: "IOC name"
  },
  {
    field: "description",
    headerName: "Description"
  },
  {
    field: "host",
    headerName: "Host",
    width: "10ch",
    sortable: false,
    filterable: false
  },
  {
    field: "network",
    headerName: "Network",
    width: "10ch",
    renderCell: (params) => {
      return params.value ? (
        <EllipsisText>{params.value}</EllipsisText>
      ) : (
        <EmptyValue />
      );
    },
    valueGetter: (params) => {
      return params.value;
    }
  }
];

const hostDetailsColumns = [
  {
    field: "status",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  {
    field: "namingName",
    headerName: "IOC name",
    sortable: false
  },
  {
    field: "description",
    headerName: "Description",
    sortable: false,
    flex: 3
  }
];

function createHostLink(host) {
  if (host?.hostId) {
    return (
      <InternalLink
        to={`/hosts/${host?.hostId}/${host.fqdn}`}
        label={`Host details, ${host?.hostName}`}
        width="100%"
      >
        {host?.hostName ? (
          <EllipsisText>{host.hostName}</EllipsisText>
        ) : (
          <EmptyValue />
        )}
      </InternalLink>
    );
  }

  return <EmptyValue />;
}

function createIocLink(id, name) {
  return (
    <InternalLink
      to={`/iocs/${id}`}
      label={`IOC details, ${name}`}
      width="100%"
    >
      <EllipsisText>{name}</EllipsisText>
    </InternalLink>
  );
}

function createTableRowForHostDetails(ioc) {
  const { id, name, namingName, activeDeployment } = ioc;

  return {
    id: id,
    status: (
      <IOCStatus
        id={ioc.id}
        activeDeployment={activeDeployment}
      />
    ),
    namingName: createIocLink(id, namingName ?? name),
    description: <IOCDescription id={ioc.id} />
  };
}

function createTableRowForExploreIocs(ioc) {
  const { id, namingName, activeDeployment } = ioc;

  return {
    id: id,
    status: (
      <IOCStatus
        id={ioc.id}
        activeDeployment={ioc.activeDeployment}
      />
    ),
    namingName: createIocLink(id, namingName),
    description: <IOCDescription id={ioc.id} />,
    host: createHostLink(activeDeployment?.host),
    network: activeDeployment?.host?.network
  };
}

export function IOCTable({
  iocs = [],
  rowType = "explore",
  loading,
  pagination,
  onPage
}) {
  const tableTypeSpecifics = {
    host: [hostDetailsColumns, createTableRowForHostDetails],
    explore: [exploreIocsColumns, createTableRowForExploreIocs]
  };

  const [columns, createRow] = tableTypeSpecifics[rowType];
  const rows = iocs.map((ioc) => createRow(ioc));

  return (
    <Table
      columns={columns}
      rows={rows}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
      disableHover
    />
  );
}
