import { useState, useEffect } from "react";
import { LabeledIcon } from "@ess-ics/ce-ui-common";
import Popover from "../../common/Popover";
import { object, bool, array } from "prop-types";
import { useTheme } from "@mui/material";
import { PlayCircleFilled, PauseCircleFilled } from "@mui/icons-material";
import { StatusPopoverContent } from "./StatusPopoverContent";
import { StatusBadge } from "./StatusBadge";
import { StatusIcon } from "./StatusIcon";
import { STATUS, statusConfig, getStatus } from "./StatusData";

const propsTypes = {
  state: object,
  alert: array,
  hideAlerts: bool
};

const checkDisplayBadge = (status, hideAlerts) => {
  return (
    !hideAlerts &&
    (status === STATUS.alert ||
      status === STATUS.warning ||
      status === STATUS.inactiveAlert ||
      status === STATUS.inactiveWarning)
  );
};

export function Status({ state, alert, hideAlerts = false }) {
  const [status, setStatus] = useState(null);
  const theme = useTheme();
  let { id } = state;

  useEffect(() => {
    setStatus(getStatus(state, alert));
  }, [state, alert]);

  return (
    <Popover
      id={`ioc-status-popover-${id}`}
      renderOwningComponent={({
        ariaOwns,
        ariaHasPopup,
        handlePopoverOpen,
        handlePopoverClose
      }) => (
        <div
          aria-owns={ariaOwns}
          aria-haspopup={ariaHasPopup}
          onMouseEnter={handlePopoverOpen}
          onMouseLeave={handlePopoverClose}
          style={{ color: theme.palette.status.icons }}
        >
          {checkDisplayBadge(status, hideAlerts) ? (
            <StatusBadge
              status={status}
              theme={theme}
            >
              <StatusIcon
                alerts={alert?.alerts ? alert.alerts : []}
                status={status}
              />
            </StatusBadge>
          ) : (
            <StatusIcon
              alerts={alert?.alerts ? alert.alerts : []}
              status={status}
            />
          )}
        </div>
      )}
      popoverContents={
        <StatusPopoverContent
          title={statusConfig[status].title}
          alerts={hideAlerts ? [] : alert?.alerts ? alert.alerts : []}
        />
      }
      anchorOrigin={{
        vertical: "top",
        horizontal: "right"
      }}
    />
  );
}

Status.propsTypes = propsTypes;

export function CommandTypeIcon({
  type,
  colorStyle = "colors",
  labelPosition = "tooltip"
}) {
  const theme = useTheme();

  const commandTypeColors = {
    start: theme.palette.status.ok.main,
    stop: theme.palette.status.fail.main
  };

  const commandTypeBlack = {
    start: theme.palette.status.icons,
    stop: theme.palette.status.icons
  };

  const colorConfig = {
    black: commandTypeBlack,
    colors: commandTypeColors
  };

  const commandTypeIcons = {
    start: {
      title: "Set to active",
      icon: PlayCircleFilled
    },
    stop: {
      title: "Set to inactive",
      icon: PauseCircleFilled
    }
  };

  const iconStyle = { fill: colorConfig[colorStyle][type.toLowerCase()] };
  const iconTitle = commandTypeIcons[type.toLowerCase()].title;
  const statusIcon = commandTypeIcons[type.toLowerCase()].icon;

  return (
    <LabeledIcon
      label={iconTitle}
      LabelProps={{ noWrap: true }}
      labelPosition={labelPosition}
      Icon={statusIcon}
      IconProps={{ style: { iconStyle } }}
    />
  );
}
